Learn R Programming

tidyrgee (version 0.1.1)

as_tidyee: as_tidy_ee

Description

The function returns a list containing the original object (Image/ImageCollection)as well as a "virtual data.frame (vrt)" which is a data.frame holding key properties of the ee$Image/ee$ImageCollection. The returned list has been assigned a new class "tidyee".

Usage

as_tidyee(x, time_end = FALSE)

Value

tidyee class object which contains a list with two components ("x","vrt")

Arguments

x

ee$Image or ee$ImageCollection

time_end

logical include time_end ("system:time_end") in vrt (default=F)

Examples

Run this code
if (FALSE) {
library(tidyrgee)
library(rgee)
ee_Initialize()
modis_ic <- ee$ImageCollection("MODIS/006/MOD13Q1")
modis_ic_tidy <- as_tidyee(modis_ic)


}

Run the code above in your browser using DataLab