Learn R Programming

tidyrgee (version 0.1.1)

mutate: mutate columns into tidyee vrt which can later be used to modify tidyee ImageCollection

Description

mutate columns into tidyee vrt which can later be used to modify tidyee ImageCollection

Value

return tidyee class object with vrt data.frame mutated.

Arguments

.data

tidyee class object (list of ee_ob, vrt)

...

mutate arguments

See Also

mutate for information about mutate on normal data tables.

Examples

Run this code
if (FALSE) {
library(tidyrgee)
library(rgee)
ee_Initialize()
modis_ic <- ee$ImageCollection("MODIS/006/MOD13Q1")
modis_ic_tidy <- as_tidyee(modis_ic)
}

Run the code above in your browser using DataLab