group_by: Group an imageCollection or tidyee object with Imagecollections by a parameter
Description
Group an imageCollection or tidyee object with Imagecollections by a parameter
Value
ee$ImageCollection with grouped_vars attribute
Arguments
.data
ee$ImageCollection or tidyee object
...
group_by variables
.add
When FALSE, the default, group_by() will
override existing groups. To add to the existing groups, use
.add = TRUE.
This argument was previously called add, but that prevented
creating a new grouping variable called add, and conflicts with
our naming conventions.
.drop
Drop groups formed by factor levels that don't appear in the
data? The default is TRUE except when .data has been previously
grouped with .drop = FALSE. See dplyr::group_by_drop_default() for details.
See Also
group_by for information about group_by on normal data tables.