powered by
mutate columns into tidyee vrt which can later be used to modify tidyee ImageCollection
return tidyee class object with vrt data.frame mutated.
tidyee class object (list of ee_ob, vrt)
mutate arguments
mutate for information about mutate on normal data tables.
mutate
if (FALSE) { library(tidyrgee) library(rgee) ee_Initialize() modis_ic <- ee$ImageCollection("MODIS/006/MOD13Q1") modis_ic_tidy <- as_tidyee(modis_ic) }
Run the code above in your browser using DataLab